@@ -7,11 +7,11 @@
 #' @name lidR-deprecated
 #' @param ... Parameters to be passed to the modern version of the function
 #' @docType package
-#' @export  cloud_metrics
-#' @aliases cloud_metrics
+#' @export
 #' @section Details:
 #' \itemize{
 #' \item{\code{\link{lasmetrics}} replace old \code{cloud_metrics}}
+#' \item{\code{\link{area}} replace old \code{lasarea}}
 #' }
 #'
 cloud_metrics = function(...)
@@ -19,4 +19,13 @@ cloud_metrics = function(...)
   .Deprecated("lasmetrics", package="lidR")
   lasmetrics(...)
 }
+
+#' @export
+#' @rdname lidR-deprecated
+#' @name lidR-deprecated
+lasarea = function(...)
+{
+  .Deprecated("lasarea", package="lidR")
+  area(...)
+}
 NULL
\ No newline at end of file
