@@ -3,7 +3,7 @@ context("terrain")
 las = lidR:::dummy_las(5000)
 las@data[, Z := Z + 0.1*X+0.1*Y+sin(0.01*X)-sin(0.1*Y)+sin(0.003*X*Y)]
 
-truedtm = lidR:::make_grid(0.5,99.5,0.5,99.5,1)
+truedtm = lidR:::make_grid(0.5,100,0.5,99.5,1)
 truedtm[, Z := 0.1*X+0.1*Y+sin(0.01*X)-sin(0.1*Y)+sin(0.003*X*Y)]
 as.lasmetrics(truedtm,1)
 data.table::setkey(truedtm, X, Y)
@@ -13,14 +13,14 @@ test_that("terrain works with knnidw", {
   data.table::setkey(dtm, X, Y)
   diff = truedtm[dtm]
   diffZ = abs(diff$Z - diff$i.Z)
-  expect_lt(mean(diffZ), 0.21)
+  expect_lt(mean(diffZ, na.rm = TRUE), 0.21)
 })
 
 test_that("terrain works with delaunay", {
   dtm = suppressWarnings(grid_terrain(las, 1, method = "delaunay"))
   data.table::setkey(dtm, X, Y)
   diff = truedtm[dtm][!is.na(i.Z)][, Z := Z - i.Z]
-  expect_lt(mean(abs(diff$Z)), 0.095)
+  expect_lt(mean(abs(diff$Z), na.rm = TRUE), 0.095)
 })
 
 test_that("terrain works with kriging", {
@@ -28,5 +28,5 @@ test_that("terrain works with kriging", {
   data.table::setkey(dtm, X, Y)
   diff = truedtm[dtm]
   diffZ = abs(diff$Z - diff$i.Z)
-  expect_lt(mean(diffZ), 0.071)
+  expect_lt(mean(diffZ, na.rm = T), 0.071)
 })
\ No newline at end of file
